@@ -8,7 +8,7 @@ class DownloadSpeedCondition(Condition):
         self._downspeed = downspeed
         self._comparer = comp
 
-    def apply(self, torrents):
+    def apply(self, client_status, torrents):
         for torrent in torrents:
             # Note: The speed unit is KiB/s
             # Note: This condition is only available for the downloading torrents
